Decentralized Instant Message (Dart Demo)

License PRs Welcome Platform Issues Repo Size Tags Version

Watchers Forks Stars Followers

Dependencies

  • Latest Versions
Name Version Description
Ming Ke Ming (名可名) Version Decentralized User Identity Authentication
Dao Ke Dao (道可道) Version Universal Message Module
DIMP (去中心化通讯协议) Version Decentralized Instant Messaging Protocol
DIM SDK Version Software Development Kit
DIM Plugins Version Cryptography & Account Plugins
Star Gate Version Network Connection Module (WebSocket)
LNC Version Log, Notification & Cache
  • pubspec.yaml
environment:
  sdk: '>=3.0.0 <4.0.0'

dependencies:
  object_key:  ^1.1.1
  lnc:         ^1.2.2
#  startrek:    ^1.2.0
  stargate:    ^1.2.0
  
#  mkm:         ^2.3.6
#  dkd:         ^2.3.6
#  dimp:        ^2.3.6
  dimsdk:      ^2.3.6
  dim_plugins: ^2.3.6

FIXME

LoadException:

../../../../../.pub-cache/hosted/pub.dev/asn1lib-1.6.5/lib/src/asn1octetstring.dart:30:26: Error: A value of type 'List<int>' can't be assigned to a variable of type 'Uint8List'.
 - 'List' is from 'dart:core'.
 - 'Uint8List' is from 'dart:typed_data'.
      this.octets = utf8.encode(octets);
                         ^
  • file: asn1lib-1.6.5/lib/src/asn1octetstring.dart
  • line: 29
  ASN1OctetString(dynamic octets, {super.tag = OCTET_STRING_TYPE}) {
    if (octets is String) {
      // We now default to utf8 encoding
      this.octets = Uint8List.fromList(octets.codeUnits);
      // this.octets = utf8.encode(octets);
    } else if (octets is Uint8List) {
      this.octets = octets;
    } else if (octets is List<int>) {
      this.octets = Uint8List.fromList(octets);
    } else {
      throw ArgumentError(
        'Parameters octets should be either of type String or List<int>.',
      );
    }
  }

Copyright © 2023-2026 Albert Moky Followers