ws library

Classes

AbstractInterruptibleChannel
Base implementation class for interruptible channels.
AbstractPairMap<K, V>
AbstractSelectableChannel
Base implementation class for selectable channels.
ActiveConnection
Active connection for client
AddressPairMap<V>
AddressPairObject
Arrival
Incoming Ship
ArrivalHall
Memory cache for Arrivals
ArrivalShip
AutoMachine<C extends MachineContext, T extends BaseTransition<C>, S extends BaseState<C, T>>
BaseChannel<C extends SelectableChannel>
BaseConnection
BaseHub
BaseMachine<C extends MachineContext, T extends BaseTransition<C>, S extends BaseState<C, T>>
BaseState<C extends MachineContext, T extends StateTransition<C>>
State with transitions
BaseTransition<C extends MachineContext>
Transition with the index of target state
ByteChannel
A channel that can read and write bytes. This interface simply unifies the {@link ReadableByteChannel} and {@link WritableByteChannel}; it does not specify any new operations.
Channel
ChannelController<C extends SelectableChannel>
Socket Channel Controller
ChannelPool
ClientGate
ClientHub
Closeable
A {@code Closeable} is a source or destination of data that can be closed. The close method is invoked to release resources that the object is holding (such as open files).
CommonGate<H extends Hub>
Gate with hub for connection
CommonHub
Connection
ConnectionDelegate
ConnectionPool
ConnectionState
Connection State
ConnectionStateBuilder
State Builder
ConnectionStateDelegate
Connection State Delegate
ConnectionStateMachine
Connection State Machine
ConnectionStateTransition
Connection State Transition
ConnectionStateTransitionBuilder
Transition Builder
DatagramChannel
A selectable channel for datagram-oriented sockets.
Departure
Outgoing Ship
DepartureHall
Memory cache for Departures
DeparturePriority
DepartureShip
Dock
Star Dock
Gate
Handler
HashPairMap<K, V>
Hub
Connections & Channels Container
InetSocketAddress
This class implements an IP Socket Address (IP address + port number) It can also be a pair (hostname + port number), in which case an attempt will be made to resolve the hostname. If resolution fails then the address is said to be unresolved but can still be used on some circumstances like connecting through a proxy.
InterruptibleChannel
LockedDock
Machine<C extends MachineContext, T extends StateTransition<C>, S extends State<C, T>>
State machine
MachineContext
State Machine Context
MachineDelegate<C extends MachineContext, T extends StateTransition<C>, S extends State<C, T>>
State Machine Delegate
Metronome
NetworkChannel
A channel to a network socket.
NIOChannel
A nexus for I/O operations.
PairMap<K, V>
PlainArrival
PlainDeparture
PlainPorter
Porter
Star Docker
PorterDelegate
PorterPool
PrimeMetronome
Processor
ReadableByteChannel
A channel that can read bytes.
Runnable
Runner
SelectableChannel
A channel that can be multiplexed via a {@link Selector}.
Ship
Star Ship
SocketAddress
This class represents a Socket Address with no protocol attachment. As an abstract class, it is meant to be subclassed with a specific, protocol dependent, implementation.
SocketChannel
A selectable channel for stream-oriented connecting sockets.
SocketHelper
SocketReader
SocketWriter
StarGate
StarPorter
Star Docker
State<C extends MachineContext, T extends StateTransition<C>>
Finite State
StateTransition<C extends MachineContext>
State Transition
StreamChannel
StreamChannelReader
StreamChannelWriter
Ticker
TimedConnection
Connection with sent/received time
WebSocketConnector
WritableByteChannel
A channel that can write bytes.

Exceptions / Errors

ClosedChannelException
Checked exception thrown when an attempt is made to invoke or complete an I/O operation upon channel that is closed, or at least closed to that operation. That this exception is thrown does not necessarily imply that the channel is completely closed. A socket channel whose write half has been shut down, for example, may still be open for reading.
IOError
Thrown when a serious I/O error has occurred.