algorithm property
String
get
algorithm
Name of the cryptographic algorithm associated with this key.
Examples: "RSA", "ECC", "AES", "DES", ...
Implementation
String get algorithm;
Name of the cryptographic algorithm associated with this key.
Examples: "RSA", "ECC", "AES", "DES", ...
String get algorithm;