DecryptKey class abstract interface

Interface for decryption keys (symmetric or asymmetric private keys).

Used to decrypt ciphertext back to plaintext:

  • Symmetric key: Same key used for encryption/decryption (e.g., AES)
  • Asymmetric private key: Paired with public key (e.g., RSA private key)
Implemented types

Properties

algorithm String
Name of the cryptographic algorithm associated with this key.
no setterinherited
data TransportableData
Encoded key material (transportable data).
no setterinherited
entries Iterable<MapEntry<String, dynamic>>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
keys Iterable<String>
no setterinherited
length int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Iterable
no setterinherited

Methods

addAll(Map<String, dynamic> other) → void
inherited
addEntries(Iterable<MapEntry<String, dynamic>> newEntries) → void
inherited
clear() → void
inherited
containsKey(Object? key) bool
inherited
containsValue(Object? value) bool
inherited
copyMap([bool deepCopy = false]) Map
Creates a copy of the internal map.
inherited
decrypt(Uint8List ciphertext, [Mapping? params]) Uint8List?
Decrypts ciphertext data using this key.
forEach(void action(String key, dynamic value)) → void
inherited
getBool(String key, [bool? defaultValue]) bool?
inherited
getDateTime(String key, [DateTime? defaultValue]) DateTime?
inherited
getDouble(String key, [double? defaultValue]) double?
inherited
getInt(String key, [int? defaultValue]) int?
inherited
getString(String key, [String? defaultValue]) String?
Gets a string value for the given key.
inherited
matchEncryptKey(EncryptKey pKey) bool
Verifies if this decryption key matches the given encryption key.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(Object? key) → dynamic
inherited
removeWhere(bool test(String key, dynamic value)) → void
inherited
setDateTime(String key, DateTime? time) → void
inherited
setMap(String key, Mapper? mapper) → void
inherited
setString(String key, Stringer? stringer) → void
inherited
toMap() MutableMapping
Returns the internal map as a Map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) → dynamic
inherited
operator []=(String key, dynamic value) → void
inherited