Meta class abstract interface

Interface for immutable metadata of network entities (users/groups).

Meta data contains core, unchanging information used to validate entities and generate their addresses/IDs. It implements Mapper for serialization to/from structured formats (Map/JSON).

Serialized format (Map/JSON):

{
  "type"        : "1",             // Algorithm version
  "key"         : "{public key}",  // Public key: PK = secp256k1(SK)
  "seed"        : "moKy",          // Entity name (seed for fingerprint)
  "fingerprint" : "..."            // Signature of seed: CT = sign(seed, SK)
}

Core algorithm:

  • Fingerprint = sign(seed, private key)
  • Used to verify the authenticity of the entity's name and public key
Implemented types
Available extensions

Properties

entries Iterable<MapEntry<String, dynamic>>
no setterinherited
fingerprint TransportableData?
Fingerprint to verify ID and public key
no setter
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
isValid bool
Validates the integrity of this metadata.
no setter
keys Iterable<String>
no setterinherited
length int
no setterinherited
publicKey VerifyKey
Public key (used for signature)
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed String?
Seed to generate fingerprint
no setter
type String
Meta algorithm version
no setter
values Iterable
no setterinherited

Methods

addAll(Map<String, dynamic> other) → void
inherited
addEntries(Iterable<MapEntry<String, dynamic>> newEntries) → void
inherited
clear() → void
inherited
containsKey(Object? key) bool
inherited
containsValue(Object? value) bool
inherited
copyMap([bool deepCopy = false]) Map
Creates a copy of the internal map.
inherited
forEach(void action(String key, dynamic value)) → void
inherited
generateAddress(int? network) Address
Generates an Address from this metadata for the specified network.
getBool(String key, [bool? defaultValue]) bool?
inherited
getDateTime(String key, [DateTime? defaultValue]) DateTime?
inherited
getDouble(String key, [double? defaultValue]) double?
inherited
getInt(String key, [int? defaultValue]) int?
inherited
getString(String key, [String? defaultValue]) String?
Gets a string value for the given key.
inherited
matchIdentifier(ID identifier) bool

Available on Meta, provided by the MetaVerifications extension

Check whether meta matches with entity ID (must call this when received a new meta from network)
matchPublicKey(VerifyKey pKey) bool

Available on Meta, provided by the MetaVerifications extension

Check whether meta matches with public key
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(Object? key) → dynamic
inherited
removeWhere(bool test(String key, dynamic value)) → void
inherited
setDateTime(String key, DateTime? time) → void
inherited
setMap(String key, Mapper? mapper) → void
inherited
setString(String key, Stringer? stringer) → void
inherited
toMap() MutableMapping
Returns the internal map as a Map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](Object? key) → dynamic
inherited
operator []=(String key, dynamic value) → void
inherited

Static Methods

create(String type, VerifyKey pKey, {String? seed, TransportableData? fingerprint}) Meta
Create from stored info
generate(String type, SignKey sKey, {String? seed}) Meta
Generate with private key
getFactory(String type) MetaFactory?
parse(Object? meta) Meta?
setFactory(String type, MetaFactory factory) → void