PorterPool class

Inheritance

Constructors

PorterPool()

Properties

hashCode int
The hash code for this object.
no setterinherited
items Iterable<Porter>
Get all mapped values
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getItem({SocketAddress? remote, SocketAddress? local}) Porter?
Get value by key pair (remote, local)
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeItem(Porter? value, {SocketAddress? remote, SocketAddress? local}) Porter?
Remove mapping by key pair (remote, local)
inherited
setItem(Porter? value, {SocketAddress? remote, SocketAddress? local}) Porter?
Set value by key pair (remote, local)
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited