TripletsHelper class abstract
- Mixed-in types
- Implementers
Constructors
- TripletsHelper(GroupDelegate delegate)
Properties
- className → String
-
no setterinherited
- database → AccountDBI?
-
no setter
- delegate → GroupDelegate
-
final
- facebook → CommonFacebook?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- messenger → CommonMessenger?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
logDebug(
String msg) → void -
inherited
-
logError(
String msg) → void -
inherited
-
logInfo(
String msg) → void -
inherited
-
logWarning(
String msg) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited