AbstractSelectableChannel class abstract
Base implementation class for selectable channels.
This class defines methods that handle the mechanics of channel registration, deregistration, and closing. It maintains the current blocking mode of this channel as well as its current set of selection keys. It performs all of the synchronization required to implement the {@link java.nio.channels.SelectableChannel} specification. Implementations of the abstract protected methods defined in this class need not synchronize against other threads that might be engaged in the same operations.
- Inheritance
-
- Object
- AbstractInterruptibleChannel
- SelectableChannel
- AbstractSelectableChannel
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBlocking → bool
-
Tells whether or not every I/O operation on this channel will block
until it completes. A newly-created channel is always in blocking mode.
no setteroverride
- isClosed → bool
-
Tells whether or not this channel is open.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< void> -
Closes this stream and releases any system resources associated
with it. If the stream is already closed then invoking this
method has no effect.
inherited
-
configureBlocking(
bool block) → SelectableChannel? -
Adjusts this channel's blocking mode.
override
-
implCloseChannel(
) → Future< void> -
Closes this channel.
inherited
-
implConfigureBlocking(
bool block) → void - Adjusts this channel's blocking mode.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited